==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/SplineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let SplineSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineSeriesBaseDescriptionMetadata.a == null) {
                SplineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineSeriesBaseDescriptionMetadata.c(SplineSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(SplineSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(SplineSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
            a.item("SplineType", "ExportedType:string:SplineType");
            a.item("SplineType@names", "Natural;Clamped");
        }
        static d(a) {
            SplineSeriesBaseDescriptionMetadata.b(a);
            a.ac("SplineSeriesBase", SplineSeriesBaseDescriptionMetadata.a);
        }
    }
    SplineSeriesBaseDescriptionMetadata.$t = markType(SplineSeriesBaseDescriptionMetadata, 'SplineSeriesBaseDescriptionMetadata');
    SplineSeriesBaseDescriptionMetadata.a = null;
    return SplineSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/SplineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let SplineSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineSeriesBaseDescriptionMetadata.a == null) {
                SplineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineSeriesBaseDescriptionMetadata.c(SplineSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(SplineSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(SplineSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
            a.item("SplineType", "ExportedType:string:SplineType");
            a.item("SplineType@names", "Natural;Clamped");
        }
        static d(a) {
            SplineSeriesBaseDescriptionMetadata.b(a);
            a.ad("SplineSeriesBase", SplineSeriesBaseDescriptionMetadata.a);
        }
    }
    SplineSeriesBaseDescriptionMetadata.$t = markType(SplineSeriesBaseDescriptionMetadata, 'SplineSeriesBaseDescriptionMetadata');
    SplineSeriesBaseDescriptionMetadata.a = null;
    return SplineSeriesBaseDescriptionMetadata;
})();
